summaryrefslogtreecommitdiffstats
path: root/mbbsd
diff options
context:
space:
mode:
authorpiaip <piaip@63ad8ddf-47c3-0310-b6dd-a9e9d9715204>2007-12-29 02:26:28 +0800
committerpiaip <piaip@63ad8ddf-47c3-0310-b6dd-a9e9d9715204>2007-12-29 02:26:28 +0800
commit49a3549d92809881652ad6ec6adad666084d7d3a (patch)
treefd348e132004df6333e6750ebe6c6608a92eab5b /mbbsd
parentdd0a2532713c555a6f96de23a4ff559f461c2ca2 (diff)
downloadpttbbs-49a3549d92809881652ad6ec6adad666084d7d3a.tar
pttbbs-49a3549d92809881652ad6ec6adad666084d7d3a.tar.gz
pttbbs-49a3549d92809881652ad6ec6adad666084d7d3a.tar.bz2
pttbbs-49a3549d92809881652ad6ec6adad666084d7d3a.tar.lz
pttbbs-49a3549d92809881652ad6ec6adad666084d7d3a.tar.xz
pttbbs-49a3549d92809881652ad6ec6adad666084d7d3a.tar.zst
pttbbs-49a3549d92809881652ad6ec6adad666084d7d3a.zip
- general message update
- modify menu permissions git-svn-id: http://opensvn.csie.org/pttbbs/trunk/pttbbs@3753 63ad8ddf-47c3-0310-b6dd-a9e9d9715204
Diffstat (limited to 'mbbsd')
-rw-r--r--mbbsd/menu.c7
-rw-r--r--mbbsd/pfterm.c23
-rw-r--r--mbbsd/pmore.c4
-rw-r--r--mbbsd/var.c2
4 files changed, 22 insertions, 14 deletions
diff --git a/mbbsd/menu.c b/mbbsd/menu.c
index 0fe12f0f..f57b622d 100644
--- a/mbbsd/menu.c
+++ b/mbbsd/menu.c
@@ -458,10 +458,10 @@ int u_customize()
int u_fixgoodpost(void); // assess.c
/* User menu */
static const commands_t userlist[] = {
- {u_customize, PERM_LOGINOK, "UUCustomize 個人化設定"},
+ {u_customize, PERM_BASIC, "UUCustomize 個人化設定"},
{u_info, PERM_LOGINOK, "IInfo 設定個人資料與密碼"},
{calendar, PERM_LOGINOK, "CCalendar 個人行事曆"},
- {u_loginview, PERM_LOGINOK, "LLogin View 選擇進站畫面"},
+ {u_loginview, PERM_BASIC, "LLogin View 選擇進站畫面"},
{u_editplan, PERM_LOGINOK, "QQueryEdit 編輯名片檔"},
{u_editsig, PERM_LOGINOK, "SSignature 編輯簽名檔"},
#if HAVE_FREECLOAK
@@ -681,8 +681,7 @@ Talk(void)
int
User(void)
{
- if (cuser.userlevel)
- domenu(M_UMENU, "個人設定", 'U', userlist);
+ domenu(M_UMENU, "個人設定", 'U', userlist);
return 0;
}
diff --git a/mbbsd/pmore.c b/mbbsd/pmore.c
index 4126f9ea..377657de 100644
--- a/mbbsd/pmore.c
+++ b/mbbsd/pmore.c
@@ -84,7 +84,7 @@
#define PMORE_MSG_WARN_FAKEUSERINFO \
" ▲此頁內容會依閱\讀者不同,原文未必有您的資料 "
#define PMORE_MSG_WARN_MOVECMD \
- " ▲此頁內容含移位碼,可能會顯示假系統訊息 "
+ " ▲此頁內容含移位碼,可能會顯示偽造的系統訊息 "
#define PMORE_MSG_SEARCH_KEYWORD \
"[搜尋]關鍵字:"
@@ -95,7 +95,7 @@
#define PMORE_MSG_MOVIE_PLAYOLD_AS24L \
"傳統動畫是以 24 行為單位設計的, 要模擬 24 行嗎? (否則會用現在的行數)[Yn] "
#define PMORE_MSG_MOVIE_PAUSE \
- " >>> 暫停播放動畫,請按任意鍵繼續。 <<<"
+ " >>> 暫停播放動畫,請按任意鍵繼續或 q 中斷。 <<<"
#define PMORE_MSG_MOVIE_PLAYING \
" >>> 動畫播放中... 可按 q, Ctrl-C 或其它任意鍵停止";
#define PMORE_MSG_MOVIE_INTERACTION_PLAYING \
diff --git a/mbbsd/var.c b/mbbsd/var.c
index 2b5e006e..88a6f348 100644
--- a/mbbsd/var.c
+++ b/mbbsd/var.c
@@ -612,7 +612,7 @@ const commands_t cmdlist[] = {
{Class, 0, "CClass 【 分組討論區 】"},
{Mail, PERM_BASIC, "MMail 【 私人信件區 】"},
{Talk, 0, "TTalk 【 休閒聊天區 】"},
- {User, 0, "UUser 【 個人設定區 】"},
+ {User, PERM_BASIC, "UUser 【 個人設定區 】"},
{Xyz, 0, "XXyz 【 系統工具區 】"},
{Play_Play, PERM_BASIC, "PPlay 【 娛樂與休閒 】"},
{Name_Menu, PERM_LOGINOK, "NNamelist 【 編特別名單 】"},
diff --git a/mbbsd/pfterm.c b/mbbsd/pfterm.c
index c0c9a516..9360acc4 100644
--- a/mbbsd/pfterm.c
+++ b/mbbsd/pfterm.c
@@ -127,13 +127,15 @@
// Some terminals prefer VT100 style scrolling, including Win/DOS telnet
#undef FTCONF_USE_ANSI_SCROLL
+#undef FTCONF_USE_VT100_SCROLL
// Few poor terminals do not have relative move (ABCD).
#undef FTCONF_USE_ANSI_RELMOVE
// Good terminals can accept any omit format (2)
// Poor terminals (eg, Win/DOS telnet) can only omit 2nd (1)
// Very few poor terminals (eg, CrazyTerm/BBMan) cannot omit any parametersa (0)
#define FTCONF_ANSICMD2_OMIT (0)
//////////////////////////////////////////////////////////////////////////
@@ -1824,12 +1826,15 @@ fterm_rawscroll (int dy)
fterm_rawcmd(ady, 1, cmd);
ft.scroll -= dy;
-#else
+#else
// VT100 flavor:
- // * ESC D: cursor down - at bottom of region, scroll up
- // * ESC M: cursor up - at top of region, scroll down
- // Elder BBS systems do \n at (rows-1) as scroll()
+ // * ESC D: scroll down
+ // * ESC M: scroll up
+ //
+ // Elder BBS systems works in a mixed way:
+ // \n at (rows-1) as scroll()
// and ESC-M at(0) as rscoll().
+ //
// SCP: CSI s / RCP: CSI u
// Warning: cannot use SCP/RCP here, because on Win/DOS telnet
// the position will change after scrolling (ex, (25,0)->(24,0).
@@ -1855,7 +1860,11 @@ fterm_rawscroll (int dy)
{
// Win/DOS telnet may have extra text in new line,
// because of the IME line.
+#ifdef FTCONF_USE_VT100_SCROLL
+ fterm_raws(ESC_STR "D" ESC_STR "[K"); // ESC_STR "[K");
+#else
fterm_raws("\n" ESC_STR "[K");
+#endif
} else {
fterm_raws(ESC_STR "M"); // ESC_STR "[K");
}
@@ -127,13 +127,15 @@
// Few poor terminals do not have relative move (ABCD).
#undef FTCONF_USE_ANSI_RELMOVE
-// Good terminals can accept any omit format (2)
-// Poor terminals (eg, Win/DOS telnet) can only omit 2nd (1)
-// Very few poor terminals (eg, CrazyTerm/BBMan) cannot omit any parametersa (0)
+// Handling ANSI commands with 2 parameters (ex, ESC[m;nH)
+// 2: Good terminals can accept any omit format (ESC[;nH)
+// 1: Poor terminals (eg, Win/DOS telnet) can only omit 2nd (ESC[mH)
+// 0: Very few poor terminals (eg, CrazyTerm/BBMan) cannot omit any parameters
#define FTCONF_ANSICMD2_OMIT (0)
//////////////////////////////////////////////////////////////////////////